@@ -119,7 +119,7 @@ df_amino_acids
 
 
 def Parse_ATOM_or_HETATM_line( line ) :
-    '''  # 2020-12-13 23:53:29 
+    '''  # 2021-04-27 11:12:31 
     parse a given line (should be ATOM or HETATM records) and return parsed data values as a numpy array (dtype = object) Parse only until xyz coordinates (because later columns are somewhat variable across different docking servers)  '''
     # parse optional fields based on the length of the entry
     value = '' if len( line ) < 60 else line[ 54 : 60 ].strip( )
@@ -130,7 +130,9 @@ def Parse_ATOM_or_HETATM_line( line ) :
     str_symbol_element = '' if len( line ) < 78 else line[ 76 : 78 ].strip( )
     str_change = '' if len( line ) < 80 else line[ 78 : 80 ].strip( )
     # parse required fields
-    return np.array( [ line[ 0 : 6 ].strip( ), int( line[ 6 : 11 ].strip( ) ), line[ 12 : 16 ].strip( ), line[ 16 ].strip( ), line[ 17 : 20 ].strip( ), line[ 21 ].strip( ), int( line[ 22 : 26 ].strip( ) ), line[ 26 ].strip( ), float( line[ 30 : 38 ].strip( ) ), float( line[ 39 : 46 ].strip( ) ), float( line[ 46 : 54 ].strip( ) ), float_occupancy, float_temperature_factor, str_id_segment, str_symbol_element, str_change ], dtype = object )
+    arr = np.array( [ line[ 0 : 6 ].strip( ), None if "*" in line[ 6 : 11 ] else int( line[ 6 : 11 ].strip( ) ), line[ 12 : 16 ].strip( ), line[ 16 ].strip( ), line[ 17 : 20 ].strip( ), line[ 21 ].strip( ), int( line[ 22 : 26 ].strip( ) ), line[ 26 ].strip( ), float( line[ 30 : 38 ].strip( ) ), float( line[ 39 : 46 ].strip( ) ), float( line[ 46 : 54 ].strip( ) ), float_occupancy, float_temperature_factor, str_id_segment, str_symbol_element, str_change ], dtype = object )
+    # atom_number might contain non-integer characters ('*****') when the atom_number is > 99999 (e.g. pdb files from 'SWISS-MODEL repositories')
+    return arr
 
 
 # In[11]:
